@@ -18,7 +18,7 @@ Method using build() override
 To initialize your app with a widget tree, override the build() method in
 your app class and return the widget tree you constructed.
 
-Here's an example of very simple application that just shows a button:
+Here's an example of a very simple application that just shows a button:
 
 .. include:: ../../examples/application/app_with_build.py
    :literal:
@@ -33,7 +33,7 @@ node).
 Method using kv file
 ~~~~~~~~~~~~~~~~~~~~
 
-You can also use the :doc:`api-kivy.lang` for creating application. The .kv can
+You can also use the :doc:`api-kivy.lang` for creating applications. The .kv can
 contain rules and root widget definitions at the same time. Here is the same
 example as the Button one in a kv file.
 
@@ -60,10 +60,10 @@ Application configuration
 Use the configuration file
 ~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-Your application might want to have his own configuration file. The :class:`App`
-is able to handle a INI file automatically. You add your section/key/value in
-the :meth:`App.build_config` method by using the `config` parameters (instance
-of :class:`~kivy.config.ConfigParser`::
+Your application might want to have its own configuration file. The
+:class:`App` is able to handle an INI file automatically. You add your
+section/key/value in the :meth:`App.build_config` method by using the `config`
+parameters (instance of :class:`~kivy.config.ConfigParser`::
 
     class TestApp(App):
         def build_config(self, config):
@@ -72,16 +72,16 @@ of :class:`~kivy.config.ConfigParser`::
                 'key2': '42'
             })
 
-As soon as you will add one section in the config, a file will be created on the
-disk, and be named from the mangled name of your class: "TestApp" will give a
-config filename "test.ini" with the content::
+As soon as you add one section in the config, a file is created on the disk, and
+named from the mangled name of your class:. "TestApp" will give a config
+file-name "test.ini" with the content::
 
     [section1]
     key1 = value1
     key2 = 42
 
-The "test.ini" will be automatically loaded at runtime, and you can access to
-the configuration in your :meth:`App.build` method::
+The "test.ini" will be automatically loaded at runtime, and you can access the
+configuration in your :meth:`App.build` method::
 
     class TestApp(App):
         def build_config(self, config):
@@ -106,10 +106,10 @@ your config tokens. Here is an example done in the KinectViewer example
     .. image:: images/app-settings.jpg
         :align: center
 
-You have the possibility to extends the default application settings with your
-own panel by extending the :meth:`App.build_settings` method. Check the
-:class:`~kivy.uix.settings.Settings` about how to create a panel, because you
-need a JSON file / data first.
+You can extend the default application settings with your own panel by extending
+the :meth:`App.build_settings` method.
+Check the class:`~kivy.uix.settings.Settings` about how to create a panel,
+because you need a JSON file / data first.
 
 Let's take as an example the previous snippet of TestApp with custom config. We
 could create a JSON like this::
@@ -142,12 +142,12 @@ options, and link them to our :data:`App.config` ConfigParser instance::
             settings.add_json_panel('Test application',
                 self.config, data=jsondata)
 
-That's all ! Now you can press F1 (default keystroke) for toggle the settings
+That's all ! Now you can press F1 (default keystroke) to toggle the settings
 panel, or press the "settings" key on your android device. You can manually call
 :meth:`App.open_settings` and :meth:`App.close_settings` if you want. Every
-changes in the panel are automatically saved in the config file.
+change in the panel is automatically saved in the config file.
 
-However, you might want to know when a config value have been changed by the
+However, you might want to know when a config value has been changed by the
 user, in order to adapt or reload your UI. You can overload the
 :meth:`on_config_change` method::
 
@@ -168,8 +168,48 @@ instance. If you don't want it, you can declare your Application like this::
         use_kivy_settings = False
         # ...
 
+
+Pause mode
+----------
+
+.. versionadded:: 1.1.0
+
+.. warning::
+
+    This mode is experimental, and designed for phones/tablets. There are some
+    cases where your application could crash on resume.
+
+On tablets and phones, the user can switch at any moment to another application.
+By default, your application will reach :func:`App.on_stop` behavior.
+
+You can support the Pause mode: when switching to another application, the
+application goes into Pause mode and waits infinitely until the user
+switches back to your application. There is an issue with OpenGL on Android
+devices: you're not ensured that the OpenGL ES Context is restored when your app
+resumes. The mechanism for restoring all the OpenGL data is not yet implemented
+into Kivy(we are looking for device with this behavior).
+
+The current implemented Pause mechanism is:
+
+    #. Kivy checks every frame, if Pause mode is activated by the Operating
+       System, due to user switching to another application, phone shutdown or
+       any other reason.
+    #. :func:`App.on_pause` is called:
+    #. If False is returned (default case), then :func:`App.on_stop` is called.
+    #. Otherwise the application will sleep until the OS will resume our App
+    #. We got a `resume`, :func:`App.on_resume` is called.
+    #. If our app memory has been reclaimed by the OS, then nothing will be
+       called.
+
+.. warning::
+
+    Both `on_pause` and `on_stop` must save important data, because after
+    `on_pause` call, on_resume may not be called at all.
+
 '''
 
+__all__ = ('App', )
+
 from inspect import getfile
 from os.path import dirname, join, exists
 from kivy.config import ConfigParser
@@ -178,6 +218,7 @@ from kivy.logger import Logger
 from kivy.event import EventDispatcher
 from kivy.lang import Builder
 from kivy.resources import resource_find
+from kivy.utils import platform
 
 
 class App(EventDispatcher):
@@ -226,6 +267,9 @@ class App(EventDispatcher):
     change this to False.
     '''
 
+    # Return the current running App instance
+    _running_app = None
+
     def __init__(self, **kwargs):
         self._app_directory = None
         self._app_name = None
@@ -234,6 +278,8 @@ class App(EventDispatcher):
         super(App, self).__init__()
         self.register_event_type('on_start')
         self.register_event_type('on_stop')
+        self.register_event_type('on_pause')
+        self.register_event_type('on_resume')
         self.built = False
 
         #: Options passed to the __init__ of the App
@@ -425,7 +471,7 @@ class App(EventDispatcher):
                 window.set_icon(icon)
             self._install_settings_keys(window)
 
-        # Run !
+        App._running_app = self
         self.dispatch('on_start')
         runTouchApp()
         self.dispatch('on_stop')
@@ -452,6 +498,42 @@ class App(EventDispatcher):
         '''
         pass
 
+    def on_pause(self):
+        '''Event handler called when pause mode is asked. You must return True
+        if you can go to the Pause mode. Otherwise, return False, and your
+        application will be stopped.
+
+        You cannot control when the application is going to this mode. It's
+        mostly used for embed devices (android/ios), and for resizing.
+
+        Default is False.
+
+        .. versionadded:: 1.1.0
+        '''
+        return False
+
+    def on_resume(self):
+        '''Event handler called when your application is resuming from the Pause
+        mode.
+
+        .. versionadded:: 1.1.0
+
+        .. warning::
+
+            When resuming, OpenGL Context might have been damaged / freed. This
+            is where you should reconstruct some of your OpenGL state, like FBO
+            content.
+        '''
+        pass
+
+    @staticmethod
+    def get_running_app():
+        '''Return the current runned application instance.
+
+        .. versionadded:: 1.1.0
+        '''
+        return App._running_app
+
     def on_config_change(self, config, section, key, value):
         '''Event handler fired when one configuration token have been changed by
         the settings page.
@@ -508,7 +590,14 @@ class App(EventDispatcher):
 
     def _on_keyboard_settings(self, window, *largs):
         key = largs[0]
-        if key == 282: # F1
+        setting_key = 282 # F1
+
+        # android hack, if settings key is pygame K_MENU
+        if platform() == 'android':
+            import pygame
+            setting_key = pygame.K_MENU
+
+        if key == setting_key:
             # toggle settings panel
             if not self.open_settings():
                 self.close_settings()
