@@ -9,9 +9,7 @@ try:
 except:
     raise
 
-import os
 from . import LabelBase
-from kivy import kivy_data_dir
 from kivy.core.image import ImageData
 
 # used for fetching extends before creature image surface
@@ -23,11 +21,10 @@ class LabelPIL(LabelBase):
 
     def _select_font(self):
         fontsize = int(self.options['font_size'] * 1.333)
-        fontname = self.options['font_name'].split(',')[0]
+        fontname = self.options['font_name_r']
         id = '%s.%s' % (unicode(fontname), unicode(fontsize))
         if not id in self._cache:
-            filename = os.path.join(kivy_data_dir, 'DejaVuSans.ttf')
-            font = ImageFont.truetype(filename, fontsize)
+            font = ImageFont.truetype(fontname, fontsize)
             self._cache[id] = font
 
         return self._cache[id]
@@ -43,8 +40,9 @@ class LabelPIL(LabelBase):
         self._pil_draw = ImageDraw.Draw(self._pil_im)
 
     def _render_text(self, text, x, y):
+        color = tuple([int(c * 255) for c in self.options['color']])
         self._pil_draw.text((int(x), int(y)),
-            text, font=self._select_font(), fill=(255, 255, 255, 255))
+            text, font=self._select_font(), fill=color)
 
     def _render_end(self):
         data = ImageData(self._size[0], self._size[1],
