@@ -265,6 +265,7 @@ class WindowBase(EventDispatcher):
     clearcolor = AliasProperty(_get_clearcolor, _set_clearcolor,
             bind=('_clearcolor', ))
     '''Color used to clear window.
+
     ::
         from kivy.core.window import Window
 
@@ -422,7 +423,7 @@ class WindowBase(EventDispatcher):
             params['left'] = Config.getint('graphics', 'left')
 
         # before creating the window
-        import kivy.core.gl
+        __import__('kivy.core.gl')
 
         # configure the window
         self.params = params
