@@ -76,36 +76,37 @@ class UIXWidgetTestCase(GraphicUnitTest):
         root.add_widget(b)
         root.add_widget(c, 2)
         r(root)
-        
+
     def test_widget_root_from_code_with_kv(self):
         from kivy.lang import Builder
         from kivy.factory import Factory
-        from kivy.properties import ObjectProperty, StringProperty
+        from kivy.properties import StringProperty
         from kivy.uix.floatlayout import FloatLayout
-        
+
         Builder.load_string("""
 <MyWidget>:
     Label:
         text: root.title
-        
+
 <BaseWidget>:
     CallerWidget:
 """)
-        
+
         class CallerWidget(FloatLayout):
+
             def __init__(self, **kwargs):
                 super(CallerWidget, self).__init__(**kwargs)
                 self.add_widget(MyWidget(title="Hello World"))
-            
+
         class NestedWidget(FloatLayout):
             title = StringProperty('aa')
-            
+
         class MyWidget(NestedWidget):
             pass
-        
+
         class BaseWidget(FloatLayout):
             pass
-        
+
         Factory.register('MyWidget', cls=MyWidget)
         Factory.register('CallerWidget', cls=CallerWidget)
 
