@@ -14,17 +14,19 @@ FileChooser
 from kivy.clock import Clock
 from kivy.lang import Builder
 from kivy.logger import Logger
+from kivy.utils import platform as core_platform
 from kivy.uix.floatlayout import FloatLayout
 from kivy.properties import StringProperty, ListProperty, BooleanProperty, \
                             ObjectProperty
-from sys import platform
 from os import listdir
 from os.path import basename, getsize, isdir, join, sep, normpath, \
                     expanduser, altsep, splitdrive
 from fnmatch import fnmatch
 
+platform = core_platform()
+
 _have_win32file = False
-if platform == 'win32':
+if platform == 'win':
     # Import that module here as it's not available on non-windows machines.
     # See http://bit.ly/i9klJE except that the attributes are defined in
     # win32file not win32com (bug on page).
@@ -76,9 +78,8 @@ class FileChooserController(FloatLayout):
     '''
 
     filters = ListProperty([])
-    '''
-    :class:`~kivy.properties.ListProperty`, defaults to [], equal to '\*'.
-    The filters to be applied to the files in the directory, e.g. ['*.png'].
+    ''':class:`~kivy.properties.ListProperty`, defaults to [], equal to '\*'.
+    The filters to be applied to the files in the directory, e.g. ['\*.png'].
     The filters are not reset when the path changes, you need to do that
     yourself if you want that. You can use the following patterns:
 
@@ -132,6 +133,14 @@ class FileChooserController(FloatLayout):
     Determines whether user is able to select multiple files.
     '''
 
+    dirselect = BooleanProperty(False)
+    '''
+    :class:`~kivy.properties.BooleanProperty`, defaults to False.
+    Determines whether directories are valid selections.
+
+    .. versionadded:: 1.1.0
+    '''
+
     def __init__(self, **kwargs):
         self.register_event_type('on_entry_added')
         self.register_event_type('on_entries_cleared')
@@ -140,17 +149,25 @@ class FileChooserController(FloatLayout):
         self.register_event_type('on_submit')
         super(FileChooserController, self).__init__(**kwargs)
 
-        if platform in ('darwin', 'linux2'):
+        self._items = []
+        self.bind(selection=self._update_item_selection)
+
+        if platform in ('macosx', 'linux', 'android', 'ios'):
             self.is_hidden = is_hidden_unix
-        elif platform == 'win32':
+        elif platform == 'win':
             self.is_hidden = is_hidden_win
         else:
-            raise NotImplementedError('Only available for Linux, OSX and Win')
+            raise NotImplementedError('Only available for Linux, OSX and Win'
+                    ' (platform is %r)' % platform)
 
         self.bind(path=self._trigger_update,
                   filters=self._trigger_update)
         self._trigger_update()
 
+    def _update_item_selection(self, *args):
+        for item in self._items:
+            item.selected = item.path in self.selection
+
     def _trigger_update(self, *args):
         Clock.unschedule(self._update_files)
         Clock.schedule_once(self._update_files)
@@ -168,9 +185,12 @@ class FileChooserController(FloatLayout):
         pass
 
     def on_submit(self, selected, touch=None):
-        self.selection = []
+        pass
 
     def entry_touched(self, entry, touch):
+        '''(internal) This method must be called by the template when an entry
+        is touched by the user.
+        '''
         if self.multiselect:
             if isdir(entry.path) and touch.is_double_tap:
                 self.open_entry(entry)
@@ -181,10 +201,27 @@ class FileChooserController(FloatLayout):
                     self.selection.append(entry.path)
         else:
             if isdir(entry.path):
-                self.open_entry(entry)
+                if self.dirselect:
+                    self.selection = [entry.path, ]
             else:
                 self.selection = [entry.path, ]
-                self.dispatch('on_submit', [entry.path], touch)
+
+    def entry_released(self, entry, touch):
+        '''(internal) This method must be called by the template when an entry
+        is touched by the user.
+
+        .. versionadded:: 1.1.0
+        '''
+        if self.multiselect:
+            pass
+        else:
+            if isdir(entry.path) and not self.dirselect:
+                self.open_entry(entry)
+            elif touch.is_double_tap:
+                if self.dirselect and isdir(entry.path):
+                    self.open_entry(entry)
+                else:
+                    self.dispatch('on_submit', self.selection, touch)
 
     def open_entry(self, entry):
         try:
@@ -193,7 +230,7 @@ class FileChooserController(FloatLayout):
             # on. Do the check here to prevent setting path to an invalid
             # directory that we cannot list.
             listdir(unicode(entry.path))
-        except OSError, e:
+        except OSError:
             #Logger.exception(e)
             entry.locked = True
         else:
@@ -220,7 +257,7 @@ class FileChooserController(FloatLayout):
             return ''
         try:
             size = getsize(fn)
-        except OSError, e:
+        except OSError:
             #Logger.exception(e)
             return '--'
 
@@ -232,11 +269,12 @@ class FileChooserController(FloatLayout):
     def _update_files(self, *args):
         # Clear current files
         self.dispatch('on_entries_cleared')
+        self._items = []
 
         # Add the components that are always needed
-        if platform == 'win32':
+        if platform == 'win':
             is_root = splitdrive(self.path)[1] in (sep, altsep)
-        elif platform in ('darwin', 'linux2'):
+        elif platform in ('macosx', 'linux', 'android', 'ios'):
             is_root = normpath(expanduser(self.path)) == sep
         else:
             # Unknown file system; Just always add the .. entry but also log
@@ -247,6 +285,7 @@ class FileChooserController(FloatLayout):
             pardir = Builder.template(self._ENTRY_TEMPLATE, **dict(name=back,
                 size='', path=back, controller=self, isdir=True, parent=None,
                 sep=sep, get_nice_size=lambda: ''))
+            self._items.append(pardir)
             self.dispatch('on_entry_added', pardir)
         try:
             self._add_files(self.path)
@@ -298,7 +337,7 @@ class FileChooserController(FloatLayout):
             return
         try:
             subentries = self._add_files(entry.path, entry)
-        except OSError, e:
+        except OSError:
             #Logger.exception(e)
             entry.locked = True
             return
