@@ -8,7 +8,7 @@ Popup
     :align: right
 
 The :class:`Popup` widget is used to create modal popups. By default, the popup
-will cover the whole "parent" window. When you are creating a Popup, you must at 
+will cover the whole "parent" window. When you are creating a Popup, you must at
 minimum set a :data:`Popup.title` and a :data:`Popup.content` widget.
 
 Remember that the default size of a Widget is size_hint=(1, 1). If you don't
@@ -52,7 +52,7 @@ can directly bind the function to an action, like an a Button's on_press ::
 Popup events
 ------------
 
-There are 2 events available: `on_open` when the popup is opening, and 
+There are 2 events available: `on_open` when the popup is opening, and
 `on_dismiss` when it is closed. For `on_dismiss`, you can prevent the
 popup from closing by explictly returning True from your callback ::
 
@@ -70,7 +70,7 @@ from kivy.logger import Logger
 from kivy.animation import Animation
 from kivy.uix.floatlayout import FloatLayout
 from kivy.properties import StringProperty, BooleanProperty, ObjectProperty, \
-    NumericProperty
+    NumericProperty, ListProperty
 
 
 class Popup(FloatLayout):
@@ -92,7 +92,7 @@ class Popup(FloatLayout):
     '''
 
     auto_dismiss = BooleanProperty(True)
-    '''Default to True, this property determines if the popup is automatically 
+    '''Default to True, this property determines if the popup is automatically
     dismissed when the user clicks outside it.
 
     :data:`auto_dismiss` is a :class:`~kivy.properties.BooleanProperty`, default
@@ -115,6 +115,57 @@ class Popup(FloatLayout):
     None.
     '''
 
+    background_color = ListProperty([0, 0, 0, .7])
+    '''Background color, in the format (r, g, b, a).
+
+    .. versionadded:: 1.1.0
+
+    :data:`background_color` is a :class:`~kivy.properties.ListProperty`,
+    default to [0, 0, 0, .7].
+    '''
+
+    background = StringProperty(
+        'atlas://data/images/defaulttheme/popup-background')
+    '''Background image of the popup used for the popup background.
+
+    .. versionadded:: 1.1.0
+
+    :data:`background` is an :class:`~kivy.properties.StringProperty`,
+    default to 'atlas://data/images/defaulttheme/popup-background'
+    '''
+
+    border = ListProperty([16, 16, 16, 16])
+    '''Border used for :class:`~kivy.graphics.vertex_instructions.BorderImage`
+    graphics instruction, used itself for :data:`background_normal` and
+    :data:`background_down`. Can be used when using custom background.
+
+    .. versionadded:: 1.1.0
+
+    It must be a list of 4 value: (top, right, bottom, left). Read the
+    BorderImage instruction for more information about how to play with it.
+
+    :data:`border` is a :class:`~kivy.properties.ListProperty`, default to (16,
+    16, 16, 16)
+    '''
+
+    separator_color = ListProperty([47 / 255., 167 / 255., 212 / 255., 1.])
+    '''Color used by the separator between title and content.
+
+    .. versionadded:: 1.1.0
+
+    :data:`background_color` is a :class:`~kivy.properties.ListProperty`,
+    default to [47 / 255., 167 / 255., 212 / 255., 1.]
+    '''
+
+    separator_height = NumericProperty(2)
+    '''Height of the separator.
+
+    .. versionadded:: 1.1.0
+
+    :data:`separator_height` is a :class:`~kivy.properties.NumericProperty`,
+    default to 2.
+    '''
+
     # Internals properties used for graphical representation.
 
     _container = ObjectProperty(None)
@@ -193,6 +244,14 @@ class Popup(FloatLayout):
         super(Popup, self).on_touch_down(touch)
         return True
 
+    def on_touch_move(self, touch):
+        super(Popup, self).on_touch_move(touch)
+        return True
+
+    def on_touch_up(self, touch):
+        super(Popup, self).on_touch_up(touch)
+        return True
+
     def on__anim_alpha(self, instance, value):
         if value == 0 and self._window is not None:
             self._window.remove_widget(self)
